@@ -1,7 +1,7 @@
 package Acme::CPANLists::Test;
 
 our $DATE = '2015-10-23'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 our @Module_Lists = (
     {
@@ -42,7 +42,7 @@ Acme::CPANLists::Test - A test CPAN lists
 
 =head1 VERSION
 
-This document describes version 0.02 of Acme::CPANLists::Test (from Perl distribution Acme-CPANLists-Test), released on 2015-10-23.
+This document describes version 0.03 of Acme::CPANLists::Test (from Perl distribution Acme-CPANLists-Test), released on 2015-10-23.
 
 =head1 DESCRIPTION
 
@@ -93,6 +93,8 @@ the same terms as the Perl 5 programming language system itself.
 
 =item * L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
+Related authors: L<SHARYANTO|https://metacpan.org/author/SHARYANTO>
+
 =back
 
 =head1 MODULE LISTS
@@ -103,8 +105,12 @@ the same terms as the Perl 5 programming language system itself.
 
 =item * L<Foo::Bar> - bar
 
+Related modules: L<Foo::Qux>
+
 =item * L<Foo::Baz> - baz
 
+Alternate modules: L<Foo::Quux>, L<Foo::Corge>
+
 =back
 
 =cut
